# Fid MCP Server

MCP server that dynamically serves tools according to `fidtools.json` or `.fidtools` configs present in the working directory. Toolkits are generated by the Fid web application and intended to allow developers to quickly onboard coding agents to their unique development environments.

To install:
```bash
claude mcp add Fid --scope user --env FID_PAT=YOUR_FID_PAT -- uvx fid-mcp
```
Note: retrieve your PAT from the user menu in your Fid project, or just use the pre-constructed install command provided by the "Connect to your Agent" button.

See [docs.fidlabs.ai](https://docs.fidlabs.ai) for more information or reach out to us at [contact@fidlabs.ai](mailto:contact@fidlabs.ai).